# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.5] - 2026-03-27

### Other
- Update .idea/inspectionProfiles/Project_Default.xml
- Update .idea/inspectionProfiles/profiles_settings.xml
- Update .idea/misc.xml
- Update .idea/modules.xml
- Update .idea/refactoring.iml
- Update .idea/vcs.xml

## [0.0.4] - 2026-03-27

## [0.0.3] - 2026-03-27

### Other
- Update MANIFEST.in

## [0.0.2] - 2026-03-27

### Test
- Update tests/test_refactoring.py

### Other
- Update refactoring/__init__.py
- Update refactoring/cli.py
- Update refactoring/core.py
- Update refactoring/utils.py

## [0.0.1] - 2026-03-27

### Other
- Update .idea/.gitignore

